@@ -69,7 +69,7 @@ class LIBSIGC_API ObjectBase
       virtual void unreference() const;
       virtual void set_manage();
 
-      ObjectBase& operator=(const ObjectBase& /* o */)
+      ObjectBase& operator=(const ObjectBase& o)
         { return *this; }
 
       ObjectBase()
@@ -79,7 +79,11 @@ class LIBSIGC_API ObjectBase
         : control_(0) {}
 
       virtual ~ObjectBase()=0;
-      
+
+      Control_* control() const 
+        { 
+          return const_cast<ObjectBase *>(this)->control(); 
+        }
       Control_* control() 
         { 
           if (!control_) 
@@ -129,7 +133,6 @@ class Ptr
       template <class T2>
       Ptr(const Ptr<T2>& p2) 
         {
-          T* test_assignment_ = (T2*)0;
           assign( p2.get() );
         }
 
@@ -144,7 +147,7 @@ class Ptr
 
       template <class T2>
       Ptr& operator=(const Ptr<T2>& p2)
-        { T *test_assignment_=(T2*)0; reset(p2.get()); return *this; }
+        { reset(p2.get()); return *this; }
     
       Ptr& operator=(const Ptr& p)
         { reset(p.get()); return *this; }
@@ -175,7 +178,7 @@ class Ptr
           if (control_)
             control_->ref();
         }
-
+      
       void reset(T* t = 0)
         {
           if (object_ == t)
@@ -197,4 +200,3 @@ class Ptr
 
 
 #endif // SIGC_OBJECT
-
